==> graphql-braid-0.10.10-sources.jar: com/atlassian/braid/MutableBraidContext.java <==
package com.atlassian.braid;

import graphql.execution.ExecutionContext;
import org.dataloader.DataLoaderRegistry;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.concurrent.atomic.AtomicReference;

import static com.atlassian.braid.java.util.BraidPreconditions.checkState;
import static java.util.Objects.requireNonNull;

final class MutableBraidContext<C> implements BraidContext<C> {
    private final AtomicReference<ExecutionContext> executionContext;
    private final DataLoaderRegistry dataLoaderRegistry;

    @Nullable
    private final C context;

    MutableBraidContext(@Nonnull DataLoaderRegistry dataLoaderRegistry, @Nullable C context) {
        this.executionContext = new AtomicReference<>();
        this.dataLoaderRegistry = requireNonNull(dataLoaderRegistry);
        this.context = context;
    }

    @Override
    public ExecutionContext getExecutionContext() {
        final ExecutionContext context = this.executionContext.get();
        checkState(context != null,
                "Method called too early, before the execution context had a chance to be set");
        return context;
    }

    ExecutionContext setExecutionContext(ExecutionContext newExecutionContext) {
        this.executionContext.set(newExecutionContext);
        return newExecutionContext;
    }

    @Override
    public DataLoaderRegistry getDataLoaderRegistry() {
        return dataLoaderRegistry;
    }

    @Override
    public C getContext() {
        return context;
    }
}

==> graphql-braid-0.13.0-sources.jar: com/atlassian/braid/MutableBraidContext.java <==
package com.atlassian.braid;

import graphql.execution.ExecutionContext;
import graphql.language.Field;
import org.dataloader.DataLoaderRegistry;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.atomic.AtomicReference;

import static com.atlassian.braid.java.util.BraidPreconditions.checkState;
import static java.util.Objects.requireNonNull;

final class MutableBraidContext<C> implements BraidContext<C> {
    private final AtomicReference<ExecutionContext> executionContext;
    private final DataLoaderRegistry dataLoaderRegistry;
    private final Map<String, List<Field>> missingFieldsByType = new HashMap<>();

    @Nullable
    private final C context;

    MutableBraidContext(@Nonnull DataLoaderRegistry dataLoaderRegistry, @Nullable C context) {
        this.executionContext = new AtomicReference<>();
        this.dataLoaderRegistry = requireNonNull(dataLoaderRegistry);
        this.context = context;
    }

    @Override
    public ExecutionContext getExecutionContext() {
        final ExecutionContext context = this.executionContext.get();
        checkState(context != null,
                "Method called too early, before the execution context had a chance to be set");
        return context;
    }

    ExecutionContext setExecutionContext(ExecutionContext newExecutionContext) {
        this.executionContext.set(newExecutionContext);
        return newExecutionContext;
    }

    @Override
    public void addMissingFields(String typeName, List<Field> fields) {
        this.missingFieldsByType.put(typeName, fields);
    }

    @Override
    public List<Field> getMissingFields(String typeName) {
        return missingFieldsByType.get(typeName);
    }

    @Override
    public DataLoaderRegistry getDataLoaderRegistry() {
        return dataLoaderRegistry;
    }

    @Override
    public C getContext() {
        return context;
    }
}
